@@ -1,7 +1,7 @@
 /* SASL server API implementation
  * Rob Siemborski
  * Tim Martin
- * $Id: client.c,v 1.54 2002/07/30 17:06:15 rjs3 Exp $
+ * $Id: client.c,v 1.57 2002/10/09 15:57:03 rjs3 Exp $
  */
 /* 
  * Copyright (c) 2001 Carnegie Mellon University.  All rights reserved.
@@ -49,6 +49,9 @@
 #include <limits.h>
 #include <ctype.h>
 #include <string.h>
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
 
 /* SASL Headers */
 #include "sasl.h"
@@ -186,8 +189,8 @@ int sasl_client_init(const sasl_callback_t *callbacks)
 {
   int ret;
   const add_plugin_list_t ep_list[] = {
-      { "sasl_client_plug_init", (void *)&sasl_client_add_plugin },
-      { "sasl_canonuser_init", (void *)&sasl_canonuser_add_plugin },
+      { "sasl_client_plug_init", (add_plugin_t *)sasl_client_add_plugin },
+      { "sasl_canonuser_init", (add_plugin_t *)sasl_canonuser_add_plugin },
       { NULL, NULL }
   };
 
@@ -233,8 +236,8 @@ static void client_dispose(sasl_conn_t *pconn)
 
   pconn->context = NULL;
 
-  if (c_conn->serverFQDN)
-      sasl_FREE(c_conn->serverFQDN);
+  if (c_conn->clientFQDN)
+      sasl_FREE(c_conn->clientFQDN);
 
   if (c_conn->cparams) {
       _sasl_free_utils(&(c_conn->cparams->utils));
@@ -275,6 +278,7 @@ int sasl_client_new(const char *service,
 		    sasl_conn_t **pconn)
 {
   int result;
+  char name[MAXHOSTNAMELEN];
   sasl_client_conn_t *conn;
   sasl_utils_t *utils;
 
@@ -314,11 +318,19 @@ int sasl_client_new(const char *service,
       MEMERROR(*pconn);
   
   utils->conn= *pconn;
+
+  /* Setup the non-lazy parts of cparams, the rest is done in
+   * sasl_client_start */
   conn->cparams->utils = utils;
   conn->cparams->canon_user = &_sasl_canon_user;
   conn->cparams->flags = flags;
   
-  result = _sasl_strdup(serverFQDN, &conn->serverFQDN, NULL);
+  /* get the clientFQDN (serverFQDN was set in _sasl_conn_init) */
+  memset(name, 0, sizeof(name));
+  gethostname(name, MAXHOSTNAMELEN);
+
+  result = _sasl_strdup(name, &conn->clientFQDN, NULL);
+
   if(result == SASL_OK) return SASL_OK;
 
   /* result isn't SASL_OK */
@@ -444,6 +456,8 @@ int sasl_client_start(sasl_conn_t *conn,
 
 	/* foreach in server list */
 	for (m = cmechlist->mech_list; m != NULL; m = m->next) {
+	    int myflags;
+	    
 	    /* Is this the mechanism the server is suggesting? */
 	    if (strcasecmp(m->plug->mech_name, name))
 		continue; /* no */
@@ -457,8 +471,15 @@ int sasl_client_start(sasl_conn_t *conn,
 		break;
 
 	    /* Does it meet our security properties? */
-	    if (((conn->props.security_flags ^ m->plug->security_flags)
-		 & conn->props.security_flags) != 0) {
+	    myflags = conn->props.security_flags;
+	    
+	    /* if there's an external layer this is no longer plaintext */
+	    if ((conn->props.min_ssf <= conn->external.ssf) && 
+		(conn->external.ssf > 1)) {
+		myflags &= ~SASL_SEC_NOPLAINTEXT;
+	    }
+
+	    if (((myflags ^ m->plug->security_flags) & myflags) != 0) {
 		break;
 	    }
 
@@ -489,7 +510,7 @@ int sasl_client_start(sasl_conn_t *conn,
 #endif
 
 	    /* compare security flags, only take new mechanism if it has
-	     * more security flags than the previous one.
+	     * all the security flags of the previous one.
 	     *
 	     * From the mechanisms we ship with, this yields the order:
 	     *
@@ -527,15 +548,15 @@ int sasl_client_start(sasl_conn_t *conn,
 	goto done;
     }
 
-    /* make cparams */
+    /* make (the rest of) cparams */
     c_conn->cparams->service = conn->service;
     c_conn->cparams->servicelen = strlen(conn->service);
     
-    c_conn->cparams->serverFQDN = c_conn->serverFQDN; 
-    c_conn->cparams->servicelen = strlen(c_conn->serverFQDN);
+    c_conn->cparams->serverFQDN = conn->serverFQDN; 
+    c_conn->cparams->slen = strlen(conn->serverFQDN);
 
-    c_conn->cparams->clientFQDN = NULL; /* XXX */
-    c_conn->cparams->clen = 0;
+    c_conn->cparams->clientFQDN = c_conn->clientFQDN; 
+    c_conn->cparams->clen = strlen(c_conn->clientFQDN);
 
     c_conn->cparams->external_ssf = conn->external.ssf;
     c_conn->cparams->props = conn->props;
