@@ -1,7 +1,7 @@
 /* saslutil.c
  * Rob Siemborski
  * Tim Martin
- * $Id: saslutil.c,v 1.36 2002/07/24 17:22:26 rjs3 Exp $
+ * $Id: saslutil.c,v 1.38 2002/09/10 15:44:12 ken3 Exp $
  */
 /* 
  * Copyright (c) 2001 Carnegie Mellon University.  All rights reserved.
@@ -45,7 +45,6 @@
 
 #include <config.h>
 #include <stdio.h>
-#include <time.h>
 #include <stdlib.h>
 #include <string.h>
 #include <assert.h>
@@ -54,9 +53,6 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <errno.h>
-#ifdef HAVE_GETTIMEOFDAY
-#include <sys/time.h>
-#endif
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
@@ -296,7 +292,7 @@ void getranddata(unsigned short ret[RPOOL_SIZE])
 	fd = open(DEV_RANDOM, O_RDONLY);
 	if(fd != -1) {
 	    unsigned char *buf = (unsigned char *)ret;
-	    size_t bytesread = 0;
+	    ssize_t bytesread = 0;
 	    size_t bytesleft = RPOOL_SIZE*sizeof(unsigned short);
 	    
 	    do {
