@@ -1,7 +1,7 @@
 /* SASL server API implementation
  * Rob Siemborski
  * Tim Martin
- * $Id: server.c,v 1.114 2002/07/30 17:06:16 rjs3 Exp $
+ * $Id: server.c,v 1.117 2002/10/02 15:50:09 ken3 Exp $
  */
 /* 
  * Copyright (c) 2001 Carnegie Mellon University.  All rights reserved.
@@ -289,8 +289,8 @@ int sasl_server_add_plugin(const char *plugname,
 			 &pluglist, &plugcount);
 
     if ((result != SASL_OK) && (result != SASL_NOUSER)) {
-	_sasl_log(NULL, SASL_LOG_WARN,
-		  "server add_plugin entry_point error %i\n", result);
+	_sasl_log(NULL, SASL_LOG_DEBUG,
+		  "server add_plugin entry_point error %z\n", result);
 	return result;
     }
 
@@ -578,13 +578,15 @@ int sasl_server_init(const sasl_callback_t *callbacks,
     int ret;
     const sasl_callback_t *vf;
     const char *pluginfile = NULL;
+#ifdef PIC
     sasl_getopt_t *getopt;
     void *context;
+#endif
 
     const add_plugin_list_t ep_list[] = {
-	{ "sasl_server_plug_init", (void *)&sasl_server_add_plugin },
-	{ "sasl_auxprop_plug_init", (void *)&sasl_auxprop_add_plugin },
-	{ "sasl_canonuser_init", (void *)&sasl_canonuser_add_plugin },
+	{ "sasl_server_plug_init", (add_plugin_t *)sasl_server_add_plugin },
+	{ "sasl_auxprop_plug_init", (add_plugin_t *)sasl_auxprop_add_plugin },
+	{ "sasl_canonuser_init", (add_plugin_t *)sasl_canonuser_add_plugin },
 	{ NULL, NULL }
     };
 
@@ -622,15 +624,16 @@ int sasl_server_init(const sasl_callback_t *callbacks,
     /* load internal plugins */
     sasl_server_add_plugin("EXTERNAL", &external_server_plug_init);
 
+#ifdef PIC
     /* delayed loading of plugins? (DSO only, as it doesn't
      * make much [any] sense to delay in the static library case) */
-    if (!_is_sasl_server_static &&
-	_sasl_getcallback(NULL, SASL_CB_GETOPT, &getopt, &context) 
+    if (_sasl_getcallback(NULL, SASL_CB_GETOPT, &getopt, &context) 
 	   == SASL_OK) {
 	/* No sasl_conn_t was given to getcallback, so we provide the
 	 * global callbacks structure */
 	ret = getopt(&global_callbacks, NULL, "plugin_list", &pluginfile, NULL);
     }
+#endif
     
     if (pluginfile != NULL) {
 	/* this file should contain a list of plugins available.
@@ -1705,19 +1708,15 @@ int sasl_checkapop(sasl_conn_t *conn,
     user[user_len] = '\0';
 
     result = prop_request(s_conn->sparams->propctx, password_request);
-    if(result != SASL_OK)
-        RETURN(conn, result);
-
-    /* Cannonify it */
-    result = _sasl_canon_user(conn, user, user_len,
-	                      SASL_CU_AUTHZID, &(conn->oparams));
     if(result != SASL_OK) 
     {
         sasl_FREE(user);
         RETURN(conn, result);
     }
 
-    result = _sasl_canon_user(conn, user, user_len, SASL_CU_AUTHID,
+    /* Cannonify it */
+    result = _sasl_canon_user(conn, user, user_len,
+	                      SASL_CU_AUTHID | SASL_CU_AUTHZID,
 	                      &(conn->oparams));
     sasl_FREE(user);
 
