@@ -1,4 +1,4 @@
-/* $Id: common.c,v 1.2 2001/12/04 02:06:52 rjs3 Exp $ */
+/* $Id: common.c,v 1.3 2002/09/03 15:11:59 rjs3 Exp $ */
 /* 
  * Copyright (c) 2001 Carnegie Mellon University.  All rights reserved.
  *
@@ -39,10 +39,11 @@
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
+#include <config.h>
+
 #include <stdio.h>
 #include <ctype.h>
 #include <stdarg.h>
-#include <sysexits.h>
 
 #include <sasl.h>
 
