@@ -49,6 +49,9 @@
 /* do we have a sys/time.h */
 #undef HAVE_SYS_TIME_H
 
+/* Are we building with doors */
+#undef USE_DOORS
+
 /* Things SASLAUTHd doesn't really care about */
 #undef HAVE_SASLAUTHD
 #undef WITH_DES
@@ -78,6 +81,9 @@
 #undef HAVE_SOCKLEN_T
 #undef HAVE_SOCKADDR_SA_LEN
 
+/* for modules that want to know if we're threaded or not */
+#undef SASLAUTHD_THREADED
+
 @BOTTOM@
 
 #ifndef HAVE___ATTRIBUTE__
